# COPR Ligenix's spec file for gsit
#
# Copyright (c) 2023-2024 Jean-Marc Liger 
#
# Forked from:
#
# COPR Ligenix's spec file for glpi
#
# Copyright (c) 2021-2023 Jean-Marc Liger 
#
# Forked from:
#
# Fedora/remirepo spec file for glpi
#
# Copyright (c) 2007-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global glpiname       glpi

%if 0%{?fedora} || 0%{?rhel} >= 8
# nginx 1.6 with nginx-filesystem
%global with_nginx     1
# httpd 2.4 with httpd-filesystem
%global with_httpd     1
%else
%global with_nginx     0
%global with_httpd     0
%endif

Name:           gsit
Version:        9.5.12
Release:        1%{?dist}
Summary:        Free IT asset management software
Summary(fr):    Gestion Libre de Parc Informatique

License:        GPLv2+ and GPLv3+ and MIT
URL:            https://github.com/DCS-Easyware/%{name}
Source0:        https://github.com/DCS-Easyware/%{name}/releases/download/%{version}/%{name}-%{version}.tgz

Source1:        %{name}-downstream.php
# override PHP configuration for php-fpm
Source2:        %{name}-user.ini
Source3:        %{name}-httpd.conf
Source4:        %{name}-nginx.conf
Source5:        %{name}-logrotate
Source6:        %{name}-README.Fedora
Source7:        %{name}-UPGRADE.Fedora

# allow to install in /usr/bin
Patch0:         %{name}-bin.patch

BuildArch:      noarch
BuildRequires:  gettext
BuildRequires:  systemd

%if %{with_httpd}
Requires:       httpd-filesystem
%endif
%if %{with_nginx}
Requires:       nginx-filesystem
%endif
%if %{with_httpd} || %{with_nginx}
Requires:       webserver
Requires:       php(httpd)
%else
Requires:       httpd, mod_php
%endif
Requires:       php(language) >= 7.4
Requires:       php-ctype
Requires:       php-curl
Requires:       php-date
Requires:       php-fileinfo
Requires:       php-filter
Requires:       php-gd
Requires:       php-intl
Requires:       php-json
Requires:       php-mbstring
Requires:       php-mysqli
Requires:       php-pcre
Requires:       php-reflection
Requires:       php-session
Requires:       php-simplexml
Requires:       php-spl
Requires:       php-xml
Requires:       php-zlib
%if 0%{?fedora} || 0%{?rhel} >= 8
# optional
Recommends:     php-apcu
Recommends:     php-exif
Recommends:     php-imap
Recommends:     php-ldap
Recommends:     php-opcache
Recommends:     php-selinux
Recommends:     php-sodium
Recommends:     php-xmlrpc
Recommends:     php-pear-CAS
%else
Requires:       php-apcu
Requires:       php-exif
Requires:       php-imap
Requires:       php-ldap
Requires:       php-sodium
Requires:       php-xmlrpc
Requires:       php-pear-CAS
%endif

Requires:         crontabs
Requires:         %{_sysconfdir}/logrotate.d
Requires(post):   %{_bindir}/systemctl
Requires(postun): %{_bindir}/systemctl

# composer dependencies 
Provides:       bundled(php-blueimp-jquery-file-upload)
Provides:       bundled(php-brick-math)
Provides:       bundled(php-container-interop-container-interop)
Provides:       bundled(php-doctrine-instantiator)
Provides:       bundled(php-elvanto-litemoji)
Provides:       bundled(php-enshrined-svg-sanitize)
Provides:       bundled(php-guzzlehttp-guzzle)
Provides:       bundled(php-guzzlehttp-promises)
Provides:       bundled(php-guzzlehttp-psr7)
Provides:       bundled(php-htmlawed-htmlawed)
Provides:       bundled(php-iamcal-lib_autolink)
Provides:       bundled(php-laminas-cache)
Provides:       bundled(php-laminas-cache-storage-adapter-apc)
Provides:       bundled(php-laminas-cache-storage-adapter-apcu)
Provides:       bundled(php-laminas-cache-storage-adapter-blackhole)
Provides:       bundled(php-laminas-cache-storage-adapter-dba)
Provides:       bundled(php-laminas-cache-storage-adapter-ext-mongodb)
Provides:       bundled(php-laminas-cache-storage-adapter-filesystem)
Provides:       bundled(php-laminas-cache-storage-adapter-memcache)
Provides:       bundled(php-laminas-cache-storage-adapter-memcached)
Provides:       bundled(php-laminas-cache-storage-adapter-memory)
Provides:       bundled(php-laminas-cache-storage-adapter-mongodb)
Provides:       bundled(php-laminas-cache-storage-adapter-redis)
Provides:       bundled(php-laminas-cache-storage-adapter-session)
Provides:       bundled(php-laminas-cache-storage-adapter-wincache)
Provides:       bundled(php-laminas-cache-storage-adapter-xcache)
Provides:       bundled(php-laminas-cache-storage-adapter-zend-server)
Provides:       bundled(php-laminas-coding-standard)
Provides:       bundled(php-laminas-eventmanager)
Provides:       bundled(php-laminas-i18n)
Provides:       bundled(php-laminas-json)
Provides:       bundled(php-laminas-loader)
Provides:       bundled(php-laminas-mail)
Provides:       bundled(php-laminas-mime)
Provides:       bundled(php-laminas-serializer)
Provides:       bundled(php-laminas-servicemanager)
Provides:       bundled(php-laminas-stdlib)
Provides:       bundled(php-laminas-validator)
Provides:       bundled(php-laminas-zendframework-bridge)
Provides:       bundled(php-mexitek-phpcolors)
Provides:       bundled(php-michelf-php-markdown)
Provides:       bundled(php-monolog-monolog)
Provides:       bundled(php-myclabs-deep-copy)
Provides:       bundled(php-paragonie-sodium_compat)
Provides:       bundled(php-phar-io-manifest)
Provides:       bundled(php-phar-io-version)
Provides:       bundled(php-phpdocumentor-reflection-common)
Provides:       bundled(php-phpdocumentor-reflection-docblock)
Provides:       bundled(php-phpdocumentor-type-resolver)
Provides:       bundled(php-phpmailer-phpmailer)
Provides:       bundled(php-phpspec-prophecy)
Provides:       bundled(php-phpunit-php-code-coverage)
Provides:       bundled(php-phpunit-php-file-iterator)
Provides:       bundled(php-phpunit-php-text-template)
Provides:       bundled(php-phpunit-php-timer)
Provides:       bundled(php-phpunit-php-token-stream)
Provides:       bundled(php-phpunit-phpunit)
Provides:       bundled(php-phpunit-phpunit-mock-objects)
Provides:       bundled(php-psr-cache)
Provides:       bundled(php-psr-container)
Provides:       bundled(php-psr-http-message)
Provides:       bundled(php-psr-log)
Provides:       bundled(php-psr-simple-cache)
Provides:       bundled(php-ralouphie-getallheaders)
Provides:       bundled(php-ramsey-collection)
Provides:       bundled(php-ramsey-uuid)
Provides:       bundled(php-rlanvin-php-rrule)
Provides:       bundled(php-sabre-dav)
Provides:       bundled(php-sabre-event)
Provides:       bundled(php-sabre-http)
Provides:       bundled(php-sabre-uri)
Provides:       bundled(php-sabre-vobject)
Provides:       bundled(php-sabre-xml)
Provides:       bundled(php-scssphp-scssphp)
Provides:       bundled(php-sebastian-code-unit-reverse-lookup)
Provides:       bundled(php-sebastian-comparator)
Provides:       bundled(php-sebastian-diff)
Provides:       bundled(php-sebastian-environment)
Provides:       bundled(php-sebastian-exporter)
Provides:       bundled(php-sebastian-global-state)
Provides:       bundled(php-sebastian-object-enumerator)
Provides:       bundled(php-sebastian-object-reflector)
Provides:       bundled(php-sebastian-recursion-context)
Provides:       bundled(php-sebastian-resource-operations)
Provides:       bundled(php-sebastian-version)
Provides:       bundled(php-simplepie-simplepie)
Provides:       bundled(php-squizlabs-php_codesniffer)
Provides:       bundled(php-symfony-console)
Provides:       bundled(php-symfony-contracts)
Provides:       bundled(php-symfony-polyfill)
Provides:       bundled(php-symfony-polyfill-ctype)
Provides:       bundled(php-symfony-polyfill-mbstring)
Provides:       bundled(php-symfony-polyfill-php73)
Provides:       bundled(php-symfony-polyfill-php80)
Provides:       bundled(php-symfony-service-contracts)
Provides:       bundled(php-tecnickcom-tcpdf)
Provides:       bundled(php-theseer-tokenizer)
Provides:       bundled(php-true-punycode)
Provides:       bundled(php-wapmorgan-unified-archive)
Provides:       bundled(php-webmozart-assert)

# node dependencies 
Provides:       bundled(js-base)
Provides:       bundled(js-chartist)
Provides:       bundled(js-codemirror)
Provides:       bundled(js-cytoscape)
Provides:       bundled(js-file-type)
Provides:       bundled(js-flatpickr)
Provides:       bundled(js-fullcalendar)
Provides:       bundled(js-fuzzy)
Provides:       bundled(js-gridstack)
Provides:       bundled(js-jquery-file-upload)
Provides:       bundled(js-jquery-gantt)
Provides:       bundled(js-jquery-prettytextdiff)
Provides:       bundled(js-jquery-rateit)
Provides:       bundled(js-jstree)
Provides:       bundled(js-leaflet)
Provides:       bundled(js-photoswipe)
Provides:       bundled(js-prismjs)
Provides:       bundled(js-scrollable-tabs)
Provides:       bundled(js-sortable)
Provides:       bundled(js-tinymce)
Provides:       bundled(js-unorm)

Provides:       glpi = %{version}-%{release}
Obsoletes:      glpi <= 9.5.13
Obsoletes:      glpi-marketplace <= 9.5.13


%description
GLPI is the Information Resource-Manager with an additional Administration-
Interface. You can use it to build up a database with an inventory for your 
company (computer, software, printers...). It has enhanced functions to make
the daily life for the administrators easier, like a job-tracking-system with
mail-notification and methods to build a database with basic information 
about your network-topology.


%description -l fr
GLPI est une application libre, distribuée sous licence GPL destinée à la
gestion de parc informatique et de helpdesk.

GLPI est composé d’un ensemble de services web écrits en PHP qui permettent
de recenser et de gérer l’intégralité des composantes matérielles ou 
logicielles d’un parc informatique, et ainsi d’optimiser le travail des
techniciens grâce à une maintenance plus cohérente.


%prep
%setup -q -n %{name}
%patch0 -p1

# check version
grep %{version} inc/define.php

# remove unused files
find vendor -name .git* -delete -print
find vendor -name \*.xml* -delete -print
find vendor -name \*.yml* -delete -print
find vendor -name \*.orig -delete -print
find vendor -name composer.json -delete -print

find vendor -name bin -type d -exec rm -rf {} + -print
find vendor -name \*.bin -delete -print
find vendor -name \*.py -delete -print
find vendor -name \*.sh -delete -print

# disable composer and node dependencies update check
sed -i -e 's/if ($needrun) {/if (false) {/g' inc/autoload.function.php

# install RPM specific constant values
cp  %{SOURCE1}  inc/downstream.php
cp  %{SOURCE2}  install/.user.ini

# rename console command in all files
for f in $(grep -r "bin/console" | cut -d":" -f1 | sort -u | grep -v ".mo"); do
        sed -i -e "s/php bin\/console/glpi-console/g" $f
        sed -i -e "s/bin\/console/glpi-console/g" $f
done

cat >cron <<EOF
# GLPI core
# Run cron to execute task even when no user connected
* * * * * apache %{_bindir}/php %{_datadir}/%{glpiname}/front/cron.php
EOF

# node dependencies
ls lib/bundles/ | grep -v min.js | sed 's/\.js/)/g' | sed -e 's/.*/Provides:       bundled(js-&/'

# composer dependencies
cd vendor
grep -ri '"name":' | grep json | grep -v { | cut -d"." -f2- | cut -d":" -f3- | sed 's/",/"/g' | sort -u | grep "/" | sed 's/\//-/g' | sed 's/ "/Provides:       bundled(php-/g' | sed 's/"/)/g'


%build
: Regenerate the locales
for po in locales/*.po
do
   msgfmt $po -o $(dirname $po)/$(basename $po .po).mo
done


%install
# application
mkdir -p %{buildroot}%{_datadir}/%{glpiname}
cp -a COPYING.txt *.php apirest.md %{buildroot}%{_datadir}/%{glpiname}/

for i in ajax css css_compiled front inc install js lib locales pics plugins public scripts sound vendor
do   cp -ar $i %{buildroot}%{_datadir}/%{glpiname}/$i
done

find %{buildroot}%{_datadir}/%{glpiname} -type f -exec chmod 644 {} \; 

# apache
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{glpiname}.conf

# nginx
%if %{with_nginx}
install -Dpm 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/nginx/default.d/%{glpiname}.conf
%endif

# config
mkdir -p %{buildroot}%{_sysconfdir}/%{glpiname}
touch %{buildroot}%{_sysconfdir}/%{glpiname}/config_db.php
touch %{buildroot}%{_sysconfdir}/%{glpiname}/local_define.php

# files
mkdir -p %{buildroot}%{_localstatedir}/lib/%{glpiname}
cp -ar files %{buildroot}%{_localstatedir}/lib/%{glpiname}/files

# log
mkdir -p %{buildroot}%{_localstatedir}/log
mv %{buildroot}%{_localstatedir}/lib/%{glpiname}/files/_log %{buildroot}%{_localstatedir}/log/%{glpiname}

install -Dpm 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{glpiname}

# cron
install -Dpm 0644 cron %{buildroot}%{_sysconfdir}/cron.d/%{glpiname}

# command
install -Dpm 0755 bin/console %{buildroot}%{_bindir}/%{glpiname}-console

# doc
install -Dpm 0644 %{SOURCE6} README.Fedora
install -Dpm 0644 %{SOURCE7} UPGRADE.Fedora


# cleanup
find %{buildroot} -name remove.txt -delete -print

# directories not in apache space
rm -f %{buildroot}%{_localstatedir}/lib/%{glpiname}/files/.htaccess
# proctection in /etc/httpd/conf.d/glpi.conf
rm -f %{buildroot}%{_datadir}/%{glpiname}/install/mysql/.htaccess
rm -f %{buildroot}%{_datadir}/%{glpiname}/locales/.htaccess
rm -f %{buildroot}%{_datadir}/%{glpiname}/scripts/.htaccess


# lang
for i in %{buildroot}%{_datadir}/%{glpiname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/%{glpiname}/locales/${lang}"
done > %{name}.lang


%post
%{_bindir}/systemctl condrestart httpd > /dev/null 2>&1 || :

%postun
%{_bindir}/systemctl condrestart httpd > /dev/null 2>&1 || :


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%doc *.txt *.md *.Fedora

%attr(2770,root,apache) %dir %{_sysconfdir}/%{glpiname}
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{glpiname}/config_db.php
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{glpiname}/local_define.php
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{glpiname}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{glpiname}
%config(noreplace) %{_sysconfdir}/cron.d/%{glpiname}
%if %{with_nginx}
%config(noreplace) %{_sysconfdir}/nginx/default.d/%{glpiname}.conf
%endif

%dir %_localstatedir/lib/%{glpiname}
# this folder can contain private information (sessions, docs, ...)
%attr(2770,root,apache) %{_localstatedir}/lib/%{glpiname}/files

%{_bindir}/%{glpiname}-console

%dir %{_datadir}/%{glpiname}
%{_datadir}/%{glpiname}/*.php
%{_datadir}/%{glpiname}/apirest.md
# license file required by installation process
%{_datadir}/%{glpiname}/COPYING.txt
%{_datadir}/%{glpiname}/ajax
%{_datadir}/%{glpiname}/css
%{_datadir}/%{glpiname}/css_compiled
%{_datadir}/%{glpiname}/front
%{_datadir}/%{glpiname}/inc
%{_datadir}/%{glpiname}/install
%{_datadir}/%{glpiname}/js
%{_datadir}/%{glpiname}/lib
%{_datadir}/%{glpiname}/pics
%{_datadir}/%{glpiname}/plugins
%{_datadir}/%{glpiname}/public
%{_datadir}/%{glpiname}/scripts
%{_datadir}/%{glpiname}/sound
%{_datadir}/%{glpiname}/vendor
%attr(770,apache,root) %dir %{_localstatedir}/log/%{glpiname}
%dir %{_datadir}/%{glpiname}/locales


%changelog
* Sat Mar 02 2024 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.12-1
- Update to 9.5.12

* Sat Jul 01 2023 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.11-3
- Correct URL and Source0
- Clean last glpi-marketplace references
- Install in /usr/share/glpi

* Wed Jun 28 2023 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.11-2
- Obsolete glpi-marketplace

* Tue Jun 20 2023 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.11-1
- Update to GSIT 9.5.11 a GLPI fork without marketplace an glpi-network
- Rename to gsit

* Sat Nov 05 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.11-1
- Update to 9.5.11
- Fix an annoying issue has been detected in one of the security fixes provided.
- The user is logged out when he tries to switch to another entity.

* Thu Nov 03 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.10-1
- Update to 9.5.10
- Comment session bug
- This is a security release, upgrading is recommended
- Security fixes:
 + CVE-2022-39276: [Low] Blind SSRF in RSS feeds and planning 
 + CVE-2022-39372: [Low] Stored XSS in user information 
 + CVE-2022-39376: [Low] Improper input validation on emails links 
 + CVE-2022-39370: [Moderate] Improper access to debug panel 
 + CVE-2022-39234: [Moderate] User's session persist after permanently deleting his account 
 + CVE-2022-39262: [Moderate] Stored XSS on login page 
 + CVE-2022-39277: [Moderate] XSS in external links 
 + CVE-2022-39375: [Moderate] XSS through public RSS feed 
 + CVE-2022-39323: [High] SQL Injection on REST API 

* Tue Oct 11 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.9-2
- Fix apache write permissions for /var/log/glpi

* Thu Sep 15 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.9-1
- Update to 9.5.9
- This is a security release, upgrading is strongly recommended
- Security fixes:
 + CVE-2022-35945: XSS through registration API
 + CVE-2022-31143: Leak of sensitive information through login page errori
 + CVE-2022-35914: [critical] Command injection using a third-party library script
 + CVE-2022-35946: SQL injection through plugin controller
 + CVE-2022-35947: [critical] Authentication via SQL injection
 + CVE-2022-36112: Blind Server-Side Request Forgery (SSRF) in RSS feeds and planning

* Mon Jul 18 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.8-1
- update to 9.5.8
  see https://github.com/glpi-project/glpi/milestone/51?closed=1
- This is a security release, upgrading is recommended
- Security fixes:
 + CVE-2022-31061: SQL injection on login page
 + CVE-2022-24868: XSS / open redirect via SVG file upload
 + CVE-2022-24869: Cross Site CSS Injection 

* Mon Apr 04 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.7-2
- fix some patch issues

* Sun Apr 03 2022 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.7-1
- update to 9.5.7
  see https://github.com/glpi-project/glpi/milestone/48?closed=1
- This is a security and bugs fix release, upgrading is recommended
- Security fixes:
 + CVE-2022-21720: SQL injection using custom CSS administration form
 + CVE-2022-21719: Reflected XSS using reload button
- fix missing mail headers in mail collector rules engine
- fix infinite loop when collecting mail attachments with the same name
- fix zero height images in mail collector
- fix duplicate ranking when rules are ordered
- fix anonymous ticket creation
- fix project cloning

* Sat Sep 25 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.6-1
- update to 9.5.6
  see https://github.com/glpi-project/glpi/milestone/47?closed=1
- This is a security and bugs fix release, upgrading is recommended
- Security fixes:
 + CVE-2021-39211: Disclosure of GLPI and server informations in telemetry endpoint
 + CVE-2021-39210: Autologin cookie accessible by scripts
 + CVE-2021-39209: Bypassable CSRF protection on ajax endpoints
 + CVE-2021-39213: Bypassable IP restriction on GLPI API using custom header injection
- fix Mailgate “Missing type for Ticket template” warning
- fix Display of images in tickets from collected mails
- fix Encoding issue with emails in GB2312 containing special characters
- fix Emails rules not working after upgrading to 9.5.5
- fix Incorrect KPIs Dashboards compared to the GLPI filter
- fix marking LDAP user as deleted after a failed password
- fix Prevent usage of date filters on full LDAP sync

* Fri May 21 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-9
- add missing systemd BuildRequires for Fedora

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-8
- update spec file's copyright, thanks again to Remy Collet!

* Sat May 15 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-7
- move marketplace in a subpackage to allow disabling it

* Thu May 13 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-6
- systemd bind mount /usr/share/glpi/marketplace
  fix to more secure   /var/lib/glpi/marketplace
  revert GLPI_MARKETPLACE_DIR override, it's broken by design
  https://mail.ow2.org/wws/arc/glpi-dev/2021-05/msg00004.html

* Sun May 09 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-5
- fix GLPI_MARKETPLACE_DIR in /var/lib/glpi/marketplace again

* Mon Apr 19 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-4
- fix GLPI_MARKETPLACE_DIR in /var/lib/glpi/marketplace

* Sat Apr 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-3
- fix "Constant GLPI_CONFIG_DIR already defined in /usr/share/glpi/inc/downstream.php" cron error
- fix some Requires and Recommand php dependencies
- update all messages in files to replace "php bin/console" with "glpi-console"

* Fri Apr 16 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-2
- add missing css_compiled and public directories

* Wed Apr 14 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.5-1
- update to 9.5.5
  see https://github.com/glpi-project/glpi/milestone/46?closed=1
- This is a security and bugs fix release, upgrading is recommended
- Security fixes:
 + CVE-2021-3486 : Stored XSS in plugins information
- fix entity creation
- removal of raw html in massive actions list
- fix issue with date_creation fields updated with older instances of MySQL servers
- fix wrong count of software counts in assets
- fix Core API errors on deprecation checks

- add new marketplace directory
- disable composer and node dependencies check message

* Mon Apr 12 2021 Jean-Marc Liger <ligenix@iscp.fr> - 9.5.4-1
- update to 9.5.4
  see https://github.com/glpi-project/glpi/milestone/45?closed=1
- This is a security release, upgrading is recommended
- Security fixes:
 + CVE-2021-21326 : Horizontal Privilege Escalation
 + CVE-2021-21255 : entities switch IDOR
 + CVE-2021-21258 : XSS injection in ajax/kanban
 + CVE-2021-21314 : XSS injection on ticket update
 + CVE-2021-21312 : Stored XSS on documents
 + CVE-2021-21313 : XSS on tabs
 + CVE-2021-21325 : Stored XSS in budget type
 + CVE-2021-21327 : Unsafe Reflection in getItemForItemtype()
 + CVE-2021-21324 : Insecure Direct Object Reference (IDOR) on "Solutions"

- remove conditionnals for EOL fedora and rhel versions
- remove unmaintained fedora/autoloader and tests

* Tue May 05 2020 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 9.4.6-1
- update to 9.4.6
- drop patches applied upstream

* Mon Feb 10 2020 Remi Collet <remi@remirepo.net> - 9.4.5-3
- switch test suite on UDS using patch from
  https://github.com/glpi-project/glpi/pull/6921
  fix FTBFS with mariadb 10.4 #1799419

* Thu Jan  9 2020 Remi Collet <remi@remirepo.net> - 9.4.5-2
- add upstream patches for PHP 7.4
- re-enable test suite

* Wed Dec 18 2019 Remi Collet <remi@remirepo.net> - 9.4.5-1
- update to 9.4.5
- disable test suite with PHP 7.4

* Tue Sep 24 2019 Remi Collet <remi@remirepo.net> - 9.4.4-1
- update to 9.4.4

* Fri Jul 19 2019 Remi Collet <remi@remirepo.net> - 9.4.3-2
- allow elvanto/litemoji 2.0
  see https://github.com/glpi-project/glpi/pull/6141
  and https://github.com/glpi-project/glpi/pull/6147

* Thu Jun 20 2019 Remi Collet <remi@remirepo.net> - 9.4.3-1
- update to 9.4.3

* Thu Apr 11 2019 Remi Collet <remi@remirepo.net> - 9.4.2-1
- update to 9.4.2

* Fri Mar 15 2019 Remi Collet <remi@remirepo.net> - 9.4.1.1-1
- update to 9.4.1.1

* Thu Mar 14 2019 Remi Collet <remi@remirepo.net> - 9.4.1-1
- update to 9.4.1

* Mon Feb 11 2019 Remi Collet <remi@remirepo.net> - 9.4.0-1
- update to 9.4.0

* Tue Jan 15 2019 Remi Collet <remi@remirepo.net> - 9.4.0~RC2-1
- update to 9.4.0 RC2

* Fri Jan  4 2019 Remi Collet <remi@remirepo.net> - 9.4.0~RC1-3
- open https://github.com/glpi-project/glpi/pull/5200 fix tests
- re-enable test suite

* Fri Dec 21 2018 Remi Collet <remi@remirepo.net> - 9.4.0~RC1-2
- fix typo in dependency name

* Fri Dec 21 2018 Remi Collet <remi@remirepo.net> - 9.4.0~RC1-1
- update to 9.4.0 RC1
- add dependency on symfony/console 3.4
- add dependency on leafo/scssphp 0.7.7
- add build dependency on mikey179/vfsStream 1.6
- drop dependency on fontawesome-fonts
- temporarily disable test suite
- add weak dependency on selinux extension

* Tue Nov 27 2018 Remi Collet <remi@remirepo.net> - 9.3.3-1
- update to 9.3.3

* Tue Nov  6 2018 Remi Collet <remi@remirepo.net> - 9.3.2-3
- add missing dependency on elvanto/litemoji

* Fri Nov  2 2018 Remi Collet <remi@remirepo.net> - 9.3.2-2
- version 9.3.2 conflicts with glpi-fusioninventory < 1:9.3+1.2
  see https://github.com/glpi-project/glpi/issues/4837

* Fri Oct 26 2018 Remi Collet <remi@remirepo.net> - 9.3.2-1
- update to 9.3.2
- open https://github.com/glpi-project/glpi/issues/4837 BC break

* Wed Sep 12 2018 Remi Collet <remi@remirepo.net> - 9.3.1-1
- update to 9.3.1

* Tue Jul  3 2018 Remi Collet <remi@remirepo.net> - 9.3.0-2
- add upstream patch to fix SQL injection CVE-2018-13049

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 9.3.0-1
- update to 9.3.0 GA
- add dependency on zend-console

* Wed Jun 20 2018 Remi Collet <remi@remirepo.net> - 9.3.0~RC2-4
- drop dependency on initscripts #1592356

* Wed Jun 20 2018 Remi Collet <remi@remirepo.net> - 9.3.0~RC2-3
- improve configuration to simply multi-glpi installation

* Thu Jun 14 2018 Remi Collet <remi@remirepo.net> - 9.3.0~RC2-2
- test build

* Tue Jun 12 2018 Remi Collet <remi@remirepo.net> - 9.3.0~RC2-1
- update to 9.3-RC2
- drop dependency on jasig/phpcas
- raise dependency on phpmailer/phpmailer 6.0
- raise dependency on zendframework 2.8
- allow sebastian/diff 2.0 and 3.0
- add dependency on monolog/monolog

* Fri Apr 27 2018 Remi Collet <remi@remirepo.net> - 9.2.3-2
- use range dependencies on F27+

* Fri Apr 27 2018 Remi Collet <remi@remirepo.net> - 9.2.3-1
- update to 9.2.3
- add dependency on sebastian/diff 1.4

* Fri Mar 16 2018 Remi Collet <remi@remirepo.net> - 9.2.2-2
- run test with --use-dot-report from atoum 3.3

* Thu Mar  1 2018 Remi Collet <remi@remirepo.net> - 9.2.2-1
- update to 9.2.2

* Thu Mar  1 2018 Remi Collet <remi@remirepo.net> - 9.2.2-0
- test build for upcomming 9.2.2

* Wed Dec 13 2017 Remi Collet <remi@remirepo.net> - 9.2.1-6
- add upstream patch to allow upgrade from 9.1.7.1

* Fri Nov 24 2017 Remi Collet <remi@remirepo.net> - 9.2.1-5
- switch to fedora/autoloader

* Sat Nov 18 2017 Remi Collet <remi@remirepo.net> - 9.2.1-4
- EL7: remove SELinux rules as default policy includes them

* Fri Nov 17 2017 Remi Collet <remi@remirepo.net> - 9.2.1-3
- properly override PHP configuration for install page

* Thu Nov 16 2017 Remi Collet <remi@remirepo.net> - 9.2.1-2
- add dependency on zendframework/zend-serializer

* Thu Nov 16 2017 Remi Collet <remi@remirepo.net> - 9.2.1-1
- update to 9.2.1

* Wed Oct 11 2017 Remi Collet <remi@remirepo.net> - 9.2-4
- move config/config_path.php to inc/downstream.php
- use /etc/glpi/local_define.php to allow local path change

* Wed Sep 27 2017 Remi Collet <remi@remirepo.net> - 9.2-3
- add missing minified JS and CSS files

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 9.2-2
- missing js and sound files

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 9.2-1
- update to 9.2

* Thu Sep 21 2017 Remi Collet <remi@remirepo.net> - 9.2-0.1.RC2
- update to 9.2RC1
- drop dependency on zetacomponents/graph
- raise dependency on zend-cache, zend-i18n 2.7
- raise dependency on sabre/vobject 4.1
- add dependency on paragonie/random_compat
- switch from phpunit to atoum for test suite

* Sat Jul 22 2017 Johan Cwiklinski <johan AT x-tnd DOT be> - 9.1.6-1
- update to 9.1.6

* Thu Jul 13 2017 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 9.1.5-1
- update to 9.1.5

* Wed Jun 14 2017 Remi Collet <remi@remirepo.net> - 9.1.4-1
- update to 9.1.4

* Fri Apr 28 2017 Remi Collet <remi@remirepo.net> - 9.1.3-1
- update to 9.1.3
- use phpunit6 on F26+
- raise dependency on simplepie/simplepie 1.5

* Sun Jan 29 2017 Remi Collet <remi@fedoraproject.org> - 9.1.2-2
- fix autoloader to allow sabre/vobject version 4

* Mon Jan 23 2017 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 9.1.2-1
- update to 9.1.2
- add missing hostname BR from MariaDB package

* Mon Jan  9 2017 Remi Collet <remi@fedoraproject.org> - 9.1.1-3
- use new tcpdf classmap autoloader

* Tue Nov 15 2016 Remi Collet <remi@fedoraproject.org> - 9.1.1-2
- update to 9.1.1
- drop runtime dependency on guzzlehttp/guzzle

* Wed Sep 28 2016 Remi Collet <remi@fedoraproject.org> - 9.1-2
- missing API documentation

* Mon Sep 26 2016 Remi Collet <remi@fedoraproject.org> - 9.1-1
- update to 9.1
  https://github.com/glpi-project/glpi/milestone/2?closed=1
- add patch to ensure correct autolading
  open https://github.com/glpi-project/glpi/pull/1056
- add patch to ensure test suite use local server
  open https://github.com/glpi-project/glpi/pull/1058

* Fri Sep 23 2016 Johan Cwiklinski <jcwiklinski@teclib.com> - 9.1-0.1.20160922gitf4143e3
- First pre-build for 9.1 series
- Drop upstream patches
- Add unit tests

* Wed Jul 27 2016 Remi Collet <remi@fedoraproject.org> - 0.90.5-1
- update to 0.90.5
  https://github.com/glpi-project/glpi/issues?q=milestone:0.90.5

* Sat Jul 23 2016 Remi Collet <remi@fedoraproject.org> - 0.90.4-2
- fix regression in document form, adding upstream patch

* Tue Jul 19 2016 Remi Collet <remi@fedoraproject.org> - 0.90.4-1
- update to 0.90.4
  https://github.com/glpi-project/glpi/issues?q=milestone:0.90.4

* Wed Jun 22 2016 Remi Collet <remi@fedoraproject.org> - 0.90.3-2
- add upstream patch, drop dependency on zend-version

* Tue Apr 12 2016 Remi Collet <remi@fedoraproject.org> - 0.90.3-1
- update to 0.90.3
  https://github.com/glpi-project/glpi/issues?q=milestone:0.90.3

* Tue Apr  5 2016 Remi Collet <remi@fedoraproject.org> - 0.90.2-2
- fix logrotate configuration for recent version

* Fri Apr  1 2016 Remi Collet <remi@fedoraproject.org> - 0.90.2-1
- update to 0.90.2

* Thu Mar 24 2016 Remi Collet <remi@fedoraproject.org> - 0.90.1-4
- add upstream patch to fix compatibility with ZF 2.5
- recommend APCu

* Thu Feb 18 2016 Remi Collet <remi@fedoraproject.org> - 0.90.1-3
- fix Zend autoloader (to allow ZF 2.5)

* Fri Nov 27 2015 Remi Collet <remi@fedoraproject.org> - 0.90.1-1
- update to 0.90.1

* Thu Oct  8 2015 Remi Collet <remi@fedoraproject.org> - 0.90-1
- update to 0.90

* Tue Oct  6 2015 Remi Collet <remi@fedoraproject.org> - 0.90-0.1.RC2
- update to 0.90-RC2

* Wed Sep 16 2015 Remi Collet <remi@fedoraproject.org> - 0.85.5-1
- update to 0.85.5
  https://github.com/glpi-project/glpi/issues?q=milestone:0.85.5
- use system ircmaxell/password-compat

* Wed Jun  3 2015 Remi Collet <remi@fedoraproject.org> - 0.85.4-2
- switch from eZ component to Zeta component

* Mon May  4 2015 Remi Collet <remi@fedoraproject.org> - 0.85.4-1
- update to 0.85.4
  https://forge.indepnet.net/versions/1136
- fix SELinux context on EL-5

* Fri Apr 17 2015 Remi Collet <remi@fedoraproject.org> - 0.85.3-1
- update to 0.85.3
  https://forge.indepnet.net/versions/1118

* Fri Feb 27 2015 Remi Collet <remi@fedoraproject.org> - 0.85.2-2
- add security fix https://forge.indepnet.net/issues/5218
- add fix for temporary directory relocation

* Wed Jan 21 2015 Remi Collet <remi@fedoraproject.org> - 0.85.2-1
- update to 0.85.2
  https://forge.indepnet.net/versions/1110

* Mon Dec 22 2014 Remi Collet <remi@fedoraproject.org> - 0.85.1-2
- increase system cron frequency and limit
- cleanup patched files

* Wed Dec 17 2014 Remi Collet <remi@fedoraproject.org> - 0.85.1-1
- update to 0.85.1
  0.85   https://forge.indepnet.net/versions/539
  0.85.1 https://forge.indepnet.net/versions/1071
- drop dependency on pear/Cache_Lite
- add dependency on php-tcpdf

* Fri Nov  7 2014 Remi Collet <remi@fedoraproject.org> - 0.84.8-2
- use httpd_var_lib_t selinux context for /var/lib/glpi
- don't rely on system selinux policy in EPEL-7
- fix apache configuration when mod_php not enabled

* Fri Oct 17 2014 Remi Collet <remi@fedoraproject.org> - 0.84.8-1
- update to 0.84.8
  https://forge.indepnet.net/versions/1072

* Sun Oct  5 2014 Remi Collet <remi@fedoraproject.org> - 0.84.7-2
- provide nginx configuration (Fedora >= 21)
- rely on system SELinux policy (Fedora >= 20, EPEL-7)

* Fri Jul 11 2014 Remi Collet <remi@fedoraproject.org> - 0.84.7-1
- update to 0.84.7
  https://forge.indepnet.net/versions/1068

* Wed Jun 18 2014 Remi Collet <remi@fedoraproject.org> - 0.84.6-1
- update to 0.84.6
  https://forge.indepnet.net/versions/1028

* Wed Feb 26 2014 Remi Collet <remi@fedoraproject.org> - 0.84.5-1
- update to 0.84.5
  https://forge.indepnet.net/projects/glpi/versions/1011

* Wed Jan 22 2014 Remi Collet <remi@fedoraproject.org> - 0.84.4-1
- update to 0.84.4
  https://forge.indepnet.net/projects/glpi/versions/993

* Thu Nov 21 2013 Remi Collet <remi@fedoraproject.org> - 0.84.3-2
- fix SELinux context #1032995
  use httpd_sys_rw_content_t instead of httpd_sys_script_rw_t

* Sun Nov  3 2013 Remi Collet <remi@fedoraproject.org> - 0.84.3-1
- update to 0.84.3
  https://forge.indepnet.net/projects/glpi/versions/973

* Wed Oct  2 2013 Remi Collet <remi@fedoraproject.org> - 0.84.2-1
- update to 0.84.2
- add upstream patch for Zend autoload
- use system ZendFramework2 and SimplePie

* Thu Sep 12 2013 Remi Collet <remi@fedoraproject.org> - 0.83.9.1-4
- restrict access for install to local for security

* Fri Aug 23 2013 Remi Collet <remi@fedoraproject.org> - 0.83.9.1-3
- drop bundled Flash files files, #1000251

* Sat Jul 27 2013 Jóhann B. Guðmundsson <johannbg@fedoraproject.org> - 0.83.9.1-2
- Add a missing requirement on crontabs to spec file

* Tue Jun 25 2013 Remi Collet <remi@fedoraproject.org> - 0.83.9.1-1
- version 0.83.91 released (security)
  https://forge.indepnet.net/versions/show/928

* Thu Jun 20 2013 Remi Collet <remi@fedoraproject.org> - 0.83.9-1
- version 0.83.9 released (security and bugfix)
  https://forge.indepnet.net/projects/glpi/versions/915

* Tue Apr  2 2013 Remi Collet <remi@fedoraproject.org> - 0.83.8-1
- version 0.83.8 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/866

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.83.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Dec  4 2012 Remi Collet <remi@fedoraproject.org> - 0.83.7-1
- version 0.83.7 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/843

* Tue Oct 16 2012 Remi Collet <remi@fedoraproject.org> - 0.83.6-1
- version 0.83.6 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/841

* Tue Oct  9 2012 Remi Collet <remi@fedoraproject.org> - 0.83.5-1
- version 0.83.5 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/800

* Fri Jul 27 2012 Remi Collet <remi@fedoraproject.org> - 0.83.4-1
- version 0.83.4 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/777

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.83.3.1-1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 12 2012 Remi Collet <remi@fedoraproject.org> - 0.83.3.1-1
- version 0.83.3 released (bugfix + security)
  https://forge.indepnet.net/projects/glpi/versions/771
- new dependency on htmLawed

* Thu May 31 2012 Remi Collet <remi@fedoraproject.org> - 0.83.2-1
- version 0.83.2 released
  https://forge.indepnet.net/projects/glpi/versions/750

* Thu Apr 19 2012 Remi Collet <remi@fedoraproject.org> - 0.83.1-2
- fix cron patch

* Wed Apr 18 2012 Remi Collet <remi@fedoraproject.org> - 0.83.1-1
- version 0.83.1 released
  0.83.1 https://forge.indepnet.net/projects/glpi/versions/696
  0.83   https://forge.indepnet.net/projects/glpi/versions/538
- adapt config for httpd 2.4

* Thu Feb 09 2012 Remi Collet <remi@fedoraproject.org> - 0.80.7-1
- version 0.80.7 released (security)
  https://forge.indepnet.net/projects/glpi/versions/685

* Thu Jan 05 2012 Remi Collet <remi@fedoraproject.org> - 0.80.6.1-1
- version 0.80.61 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/677

* Thu Jan 05 2012 Remi Collet <remi@fedoraproject.org> - 0.80.6-1
- version 0.80.6 released (bugfix)
  https://forge.indepnet.net/projects/glpi/versions/657
- add patch for https://forge.indepnet.net/issues/3299

* Wed Nov 30 2011 Remi Collet <remi@fedoraproject.org> - 0.80.5-1
- version 0.80.5 released (bugfix)
  0.80.5 https://forge.indepnet.net/projects/glpi/versions/643
  0.80.4 https://forge.indepnet.net/projects/glpi/versions/632
  0.80.3 https://forge.indepnet.net/projects/glpi/versions/621
  0.80.2 https://forge.indepnet.net/projects/glpi/versions/605
  0.80.1 https://forge.indepnet.net/projects/glpi/versions/575
  0.80   https://forge.indepnet.net/projects/glpi/versions/466
- increase cron run frequency (3 tasks each 3 minutes)

* Sun Jul 24 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.78.5-3.svn14966
- use system EZC only if available (not in EL-5)

* Fri Jul 22 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.78.5-2.svn14966
- bug and security fix from SVN.

* Sat Jun 11 2011 Remi Collet <Fedora@FamilleCollet.com> - 0.78.5-1
- version 0.78.5 released

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.72.4-4.svn11497
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu May 20 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.72.4-3.svn11497
- use system phpCAS instead of bundled copy
- minor bug fixes from SVN

* Mon Mar 22 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.72.4-2.svn11035
- update embedded phpCAS to 1.1.0RC7 (security fix - #575906)

* Tue Mar  2 2010 Remi Collet <Fedora@FamilleCollet.com> - 0.72.4-1
- update to 0.72.4

* Tue Oct 27 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.72.3-1
- update to 0.72.3

* Wed Sep 09 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.72.2.1-1
- update to 0.72.21

* Tue Aug 18 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.72.1-1.svn8743
- update to 0.72.1 svn revision 8743
- use system PHPMailer
- now requires php > 5

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.71.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 02 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.71.6-1
- update to 0.71.6 (Bugfix Release)

* Fri May 22 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.71.5-4
- post 0.71.5 patches (7910=>8321)

* Sun Apr 26 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.71.5-3
- post 0.71.5 patches (7910=>8236)

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.71.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 26 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.71.5-1
- update to 0.71.5 (Fix regression in 0.71.4)

* Mon Jan 26 2009 Remi Collet <Fedora@FamilleCollet.com> - 0.71.4-1
- update to 0.71.4 (Security Release)

* Sun Nov 30 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71.3-1
- update to 0.71.3 (bugfix release)

* Sun Sep 28 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71.2-1.el4.1
- Fix MySQL 4.1 compatibility issue

* Mon Sep 15 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71.2-1
- update to 0.71.2 bugfix

* Sat Aug 09 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71.1-2
- fix SElinux bug on install test (glpi-check.patch)
- add create option on logrotate conf

* Fri Aug 01 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71.1-1
- update to 0.71.1 bugfix
- use system cron
- increase memory_limit / max_execution_time for upgrade

* Fri Jul 11 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.71-1
- update to 0.71 stable
- fix bug #452353 (selinux)

* Fri Apr 25 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.2-3
- remplace module policy by simple semanage (#442706)

* Mon Jan 28 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.2-2
- rebuild (fix sources tarball)

* Sun Jan 27 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.2-1
- bugfixes update 

* Tue Jan 15 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.1a-1
- update 

* Sun Jan 13 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.1-2
- fix typo in lang files

* Sun Jan 13 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70.1-1
- update to 0.70.1 (0.70 + bugfixes)

* Thu Jan 03 2008 Remi Collet <Fedora@FamilleCollet.com> - 0.70-4
- Changeset 6226 + 6228
- disable SELinux in EL-5

* Sat Dec 29 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-3
- Changeset 6191 + 6194 + 6196

* Fri Dec 28 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-2
- Changeset 6190

* Fri Dec 21 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-1
- 0.70 final

* Fri Nov 16 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-0.4.rc3
- Release Candidate 3

* Thu Nov 01 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-0.3.rc2
- correct source

* Thu Nov 01 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-0.2.rc2
- Release Candidate 2

* Mon Oct 08 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-0.2.rc1
- From review #322781 : fix Source0 and macros
- Requires php-domxml for EL4

* Sun Sep 30 2007 Remi Collet <Fedora@FamilleCollet.com> - 0.70-0.1.rc1
- GLPI Version 0.7-RC1
- initial SPEC for Fedora Review

* Thu May 03 2007 Remi Collet <RPMS@FamilleCollet.com> - 0.70-0.beta.20070503
- initial RPM

